pub struct ValidTransform(Transform);Expand description
A transform that has been checked to be invertible.
We need to validate user-supplied transforms before setting them on Cairo, so we use this type for that.
Tuple Fields
0: TransformMethods from Deref<Target = Transform>
pub fn pre_transform(&self, t: &Transform) -> Self
pub fn post_transform(&self, t: &Transform) -> Self
pub fn pre_translate(&self, x: f64, y: f64) -> Self
pub fn pre_scale(&self, sx: f64, sy: f64) -> Self
pub fn pre_rotate(&self, angle: Angle) -> Self
pub fn post_translate(&self, x: f64, y: f64) -> Self
pub fn post_scale(&self, sx: f64, sy: f64) -> Self
pub fn post_rotate(&self, angle: Angle) -> Self
fn determinant(&self) -> f64
pub fn is_invertible(&self) -> bool
pub fn invert(&self) -> Option<Self>
pub fn transform_distance(&self, dx: f64, dy: f64) -> (f64, f64)
pub fn transform_point(&self, px: f64, py: f64) -> (f64, f64)
pub fn transform_rect(&self, rect: &Rect) -> Rect